import {FC, FormEventHandler} from 'react'
import styled from 'styled-components'
import TextInput from '../../../molecules/forms/TextInput'
import TextArea from '../../../molecules/forms/TextArea'
import ActionButton from '../../../molecules/forms/ActionButton'

const Form = styled('form')({
	display: 'grid',
	gap: '1rem',
})

type Props = {
	onSubmit?: FormEventHandler,
	action?: string,
	labels: Record<string, string>,
}

const CreateRingtoneForm: FC<Props> = ({
	onSubmit,
	action,
	labels,
}) => {
	return (
		<Form
			onSubmit={onSubmit}
			method="post"
			action={action}
			aria-label={labels['form']}
		>
			<TextInput
				label={labels['name'] || 'Name'}
				name="name"
				block
			/>
			<TextArea
				label={labels['data'] || 'Data'}
				name="data"
				block
			/>
			<ActionButton
				type="submit"
				block
			>
				{labels['cta'] || 'Post'}
			</ActionButton>
		</Form>
	)
}

export default CreateRingtoneForm
