import {FastifyInstance} from 'fastify'
import {build} from '../../helper'
import ringtoneModule from '../../../src/modules/ringtone'
import MockRingtoneRepository from '../../mocks/repositories/Ringtone'

describe('ringtone resource', () => {
	let app: FastifyInstance

	beforeEach(async () => {
		ringtoneModule.registerInstance('RingtoneRepository', new MockRingtoneRepository([
			{
				id: '00000000-0000-0000-000000000000',
				name: 'Ringtone 1',
				data: '4c4',
				createdAt: new Date('2021-05-01'),
				updatedAt: new Date('2021-05-01'),
				deletedAt: null,
				composerId: '00000000-0000-0000-000000000000',
			},
			{
				id: '00000000-0000-0000-000000000001',
				name: 'Ringtone 2',
				data: '4c4 8c4',
				createdAt: new Date('2021-05-01'),
				updatedAt: new Date('2021-05-01'),
				deletedAt: null,
				composerId: '00000000-0000-0000-000000000000',
			},
			{
				id: '00000000-0000-0000-000000000002',
				name: 'Deleted Ringtone 1',
				data: '4c4',
				createdAt: new Date('2021-05-01'),
				updatedAt: new Date('2021-05-01'),
				deletedAt: new Date('2021-05-05'),
				composerId: '00000000-0000-0000-000000000000',
			}
		]))
		app = await build()
	})

	afterEach(async () => {
		ringtoneModule.clearInstances()
		await app.close()
	})

	describe('collection', () => {
		it('should be browsable', async () => {
			const res = await app.inject({
				url: '/api/ringtones',
				method: 'GET',
			})
			const parsedPayload = JSON.parse(res.payload)
			expect(Array.isArray(parsedPayload.data)).toBe(true)
		})

		it('should be searchable', async () => {
			// TODO
		})

		it('should be extendable', async () => {
			const res = await app.inject({
				url: '/api/ringtones',
				method: 'POST',
				headers: {
					'Content-Type': 'application/json',
				},
				payload: JSON.stringify({
					name: 'New Ringtone',
					data: '4c4',
					composerId: '00000000-0000-0000-000000000000',
				})
			})
			const parsedPayload = JSON.parse(res.payload)
			expect(parsedPayload.data).toEqual({
				id: expect.any(String),
				name: 'New Ringtone',
				data: '4c4',
				createdAt: expect.any(String),
				updatedAt: expect.any(String),
				deletedAt: null,
				composerId: '00000000-0000-0000-000000000000',
			})
			console.log(parsedPayload)
		})
	})
})
